use std::path::PathBuf;

use clap::{Args, Parser, Subcommand, ValueEnum};

#[derive(Debug, Parser, PartialEq, Eq)]
#[command(version, about, author, long_about = None, args_override_self = true)]
pub struct CliArgs {
	#[command(subcommand)]
	pub commands: Commands,
}

#[derive(Debug, Subcommand, PartialEq, Eq)]
pub enum Commands {
	Init,
	Tag(TagArgs),
	Tags(TagsArgs),
	Files(FilesArgs),
}

#[derive(Debug, Args, PartialEq, Eq)]
pub struct TagsArgs {
	pub query: Option<String>,

	#[command(subcommand)]
	pub commands: Option<TagsCommands>,
}

#[derive(Debug, Subcommand, PartialEq, Eq)]
pub enum TagsCommands {
	List,
	Add { add: Vec<String> },
	Remove { remove: Vec<String> },
}

#[derive(Debug, Args, PartialEq, Eq)]
pub struct TagArgs {
	pub file: PathBuf,

	pub tags: Vec<String>,
}

#[derive(Debug, Args, PartialEq, Eq)]
pub struct FilesArgs {
	pub query: Option<String>,
}
